@@ -482,6 +482,9 @@ class Client:
         data = await self._connection.get(
             f"https://api.porsche.com/service-vehicle/service-access/{vin}/details"
         )
+        # Find out if we're in privacy mode
+        is_privacy = data['vehicleServiceEnabledMap']['VSR'] == 'DISABLED'
+        data["privacyMode"] = is_privacy
         return data
 
     async def getCapabilities(self, vin):
