@@ -61,19 +61,18 @@ class Connection:
         self.porscheAPIToken: Text = "https://login.porsche.com/as/token.oauth2"
         self.porscheAPI: Text = "https://connect-portal.porsche.com/core/api/v3/de/de_DE"
         self.porscheApplications = {
-                'portal': {
-                    'client_id': 'TZ4Vf5wnKeipJxvatJ60lPHYEzqZ4WNp',
-                    'redirect_uri': 'https://my-static02.porsche.com/static/cms/auth.html',
-                    'prefix': 'https://api.porsche.com/core/api/v3/'
+                'api': {
+                    'client_id': '4mPO3OE5Srjb1iaUGWsbqKBvvesya8oA',
+                    'redirect_uri': 'https://my.porsche.com/core/de/de_DE',
+                    'prefix': 'https://api.porsche.com/core/api/'
                     },
                 'auth': {
                     'client_id': '4mPO3OE5Srjb1iaUGWsbqKBvvesya8oA',
                     'redirect_uri': 'https://my.porsche.com/core/de/de_DE/',
-                    'prefix': 'https://api.porsche.com/core/api/v2/'
+                    'prefix': 'https://login.porsche.com'
                     },
                 'carcontrol': {
                     'client_id': 'Ux8WmyzsOAGGmvmWnW7GLEjIILHEztAs',
-                    #'client_id': 'imeVsv86TpjM9beWJqI0sNMAip6ga05O',
                     'redirect_uri':  'https://my.porsche.com/myservices/auth/auth.html',
                     'prefix': 'https://api.porsche.com/'
                     }
@@ -230,6 +229,7 @@ class Connection:
             self.tokens[application['client_id']] = token
         head = {
             "Authorization": f"Bearer {token['access_token']}",
+            "origin": "https://my.porsche.com",
             "apikey": token['apikey'],
             "x-vrs-url-country": self.country.lower(),
             "x-vrs-url-language": f"{self.language.lower()}_{self.country.upper()}"
